==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ast.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividaes",
    "Error loading activities" : "Fallu al cargar les actividaes",
    "No activities" : "Nun hai actividaes",
    "Load more activities" : "Cargar más actividaes",
    "This stream will show events like additions, changes & shares" : "Esti fluxu amosará eventos como amiestos, camudancies y comparticiones",
    "There are no events for this filter" : "Nun hai eventos pa esta peñera",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "Activity" : "Actividá",
    "Personal activity feed for %s" : "Feed d'actividá personal pa %s",
    "Your feed URL is invalid" : "La URL del to feed nun ye válida",
    "Your settings have been updated." : "Anováronse los tos axustes.",
    "Mail" : "Corréu",
    "Stream" : "Fluxu de rede",
    "\"remote user\"" : "«usuariu remotu»",
    "Activity notification" : "Avisu d'actividá",
    ", " : ", ",
    "%s and %s" : "%s y %s",
    "Hello %s," : "Hola %s,",
    "You are receiving this email because the following things happened at %s" : "Tas recibiendo esti corréu porque asocedieron les coses de darréu en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* y %n más ","* y %n más "],
    "Notify about your own actions via email" : "Avisar per corréu tocante a les mios propies aiciones",
    "You need to set up your email address before you can receive notification emails." : "Precises configurar la to direición de corréu enantes que pueas recibir correos d'avisu.",
    "Send emails:" : "Unviar correos:",
    "Hourly" : "Cada hora",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "Activity feed" : "Feed d'actividá",
    "Enable RSS feed" : "Habilitar feed RSS",
    "No activity yet" : "Entá nun hai actividá",
    "No more events to load" : "Nun hai más eventos pa cargar",
    "Files" : "Ficheros"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-12.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/ast.js <==
OC.L10N.register(
    "activity",
    {
    "Activities" : "Actividaes",
    "An error occurred while loading activities" : "Asocedió un fallu entrín se cargaben les actividaes",
    "No activity yet" : "Entá nun hai actividaes",
    "Load more activities" : "Cargar más actividaes",
    "Copied!" : "¡Copióse",
    "Not supported!" : "¡Nun se sofita!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar .",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "{name} (invisible)" : "{name} (invisible)",
    "in {path}" : "en {path}",
    "This stream will show events like additions, changes & shares" : "Esti fluxu amosará eventos como amiestos, camudancies y comparticiones",
    "There are no events for this filter" : "Nun hai eventos pa esta peñera",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "Personal activity feed for %s" : "Feed d'actividá personal pa %s",
    "Your feed URL is invalid" : "La URL del to feed nun ye válida",
    "Your settings have been updated." : "Anováronse los tos axustes.",
    "Settings have been updated." : "Anováronse los axustes.",
    "Mail" : "Corréu",
    "Stream" : "Fluxu de rede",
    "All activities" : "Toles actividaes",
    "By others" : "Por otros",
    "By you" : "Por ti",
    "\"remote user\"" : "«usuariu remotu»",
    "Hello %s" : "%sHola ",
    "Hello %s," : "Hola %s,",
    "There was some activity at %s" : "Hebo dalgo d'actividá en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más"],
    "Activity notification" : "Avisu d'actividá",
    ", " : ", ",
    "%s and %s" : "%s y %s",
    "Activity" : "Actividá",
    "Activity feed" : "Feed d'actividá",
    "Notify about your own actions via email" : "Avisar per corréu tocante a les mios propies aiciones",
    "You need to set up your email address before you can receive notification emails." : "Precises configurar la to direición de corréu enantes que pueas recibir correos d'avisu.",
    "Send emails:" : "Unviar correos:",
    "Hourly" : "Cada hora",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "Settings" : "Axustes",
    "Enable RSS feed" : "Habilitar feed RSS",
    "No more events to load" : "Nun hai más eventos pa cargar",
    "Files" : "Ficheros"
},
"nplurals=2; plural=(n != 1);");
